@@ -1,9 +1,8 @@
 from .private import private
 from .public import public
-from .types import ModuleAware
 
 
-__version__ = '2.1.3'
+__version__ = '3.0.1'
 
 
 def install() -> None:
@@ -14,8 +13,15 @@ def install() -> None:
     builtins.private = private          # type: ignore [attr-defined]
 
 
+# mypy does not understand that __all__ gets populated at runtime via the
+# following call,
+__all__ = [
+    'private',
+    'public',
+]
+
+
 public(
-    ModuleAware=ModuleAware,
-    public=public,
     private=private,
+    public=public,
 )
